@@ -33,10 +33,15 @@
 from gettext import gettext as _
 import logging
 
-from gi.repository import Gtk, Gio, GLib, Gdk
+from gi.repository import Gtk, Gio, GLib, Gdk, GObject
 
 from gnomemusic import log
-from gnomemusic.mpris import MediaPlayer2Service
+from gnomemusic.coremodel import CoreModel
+from gnomemusic.coreselection import CoreSelection
+from gnomemusic.inhibitsuspend import InhibitSuspend
+from gnomemusic.mpris import MPRIS
+from gnomemusic.pauseonsuspend import PauseOnSuspend
+from gnomemusic.player import Player
 from gnomemusic.widgets.aboutdialog import AboutDialog
 from gnomemusic.window import Window
 
@@ -50,7 +55,6 @@ class Application(Gtk.Application):
         super().__init__(
             application_id=application_id,
             flags=Gio.ApplicationFlags.FLAGS_NONE)
-
         self.props.resource_base_path = "/org/gnome/Music"
         GLib.set_application_name(_("Music"))
         GLib.set_prgname(application_id)
@@ -58,7 +62,15 @@ class Application(Gtk.Application):
 
         self._init_style()
         self._window = None
-        self._application_id = application_id
+
+        self._coreselection = CoreSelection()
+        self._coremodel = CoreModel(self)
+
+        self._settings = Gio.Settings.new('org.gnome.Music')
+        self._player = Player(self)
+
+        InhibitSuspend(self)
+        PauseOnSuspend(self._player)
 
     def _init_style(self):
         css_provider = Gtk.CssProvider()
@@ -68,6 +80,55 @@ class Application(Gtk.Application):
         style_context.add_provider_for_screen(
             screen, css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
 
+    @GObject.Property(
+        type=Player, default=None, flags=GObject.ParamFlags.READABLE)
+    def player(self):
+        """Get application-wide music player.
+
+        :returns: the player
+        :rtype: Player
+        """
+        return self._player
+
+    @GObject.Property(
+        type=Gio.Settings, flags=GObject.ParamFlags.READABLE)
+    def settings(self):
+        """Get application-wide settings.
+
+        :returns: settings
+        :rtype: Gio.settings
+        """
+        return self._settings
+
+    @GObject.Property(
+        type=CoreModel, flags=GObject.ParamFlags.READABLE)
+    def coremodel(self):
+        """Get class providing all listmodels.
+
+        :returns: List model provider class
+        :rtype: CoreModel
+        """
+        return self._coremodel
+
+    @GObject.Property(
+        type=CoreSelection, flags=GObject.ParamFlags.READABLE)
+    def coreselection(self):
+        """Get selection object.
+
+        :returns: Object containing all selection info
+        :rtype: CoreSelection
+        """
+        return self._coreselection
+
+    @GObject.Property(type=Window, flags=GObject.ParamFlags.READABLE)
+    def window(self):
+        """Get main window.
+
+        :returns: Main window.
+        :rtype: Window
+        """
+        return self._window
+
     @log
     def _build_app_menu(self):
         action_entries = [
@@ -106,12 +167,9 @@ class Application(Gtk.Application):
     def do_activate(self):
         if not self._window:
             self._window = Window(self)
-            self._window.set_default_icon_name(self._application_id)
-            if self._application_id == 'org.gnome.MusicDevel':
+            self._window.set_default_icon_name(self.props.application_id)
+            if self.props.application_id == 'org.gnome.MusicDevel':
                 self._window.get_style_context().add_class('devel')
-            MediaPlayer2Service(self)
+            MPRIS(self)
 
-        # gtk_window_present does not work on Wayland.
-        # Use gtk_present_with_time as a workaround instead.
-        # See https://gitlab.gnome.org/GNOME/gtk/issues/624#note_10996
-        self._window.present_with_time(GLib.get_monotonic_time() / 1000)
+        self._window.present()
